@@ -17,7 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
 
-/* $Id: pcsc_scan.c 4192 2009-05-10 15:48:14Z rousseau $ */
+/* $Id: pcsc_scan.c 5161 2010-08-18 21:36:11Z rousseau $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -69,8 +69,8 @@ int main(int argc, char *argv[])
 	int current_reader;
 	LONG rv;
 	SCARDCONTEXT hContext;
-	SCARD_READERSTATE_A *rgReaderStates_t = NULL;
-	SCARD_READERSTATE_A rgReaderStates[1];
+	SCARD_READERSTATE *rgReaderStates_t = NULL;
+	SCARD_READERSTATE rgReaderStates[1];
 	DWORD dwReaders = 0, dwReadersOld;
 	DWORD timeout;
 	LPSTR mszReaders = NULL;
